"""Top-level package for Outlook Mail."""

__author__ = """Luis Gabriel Gonçalves Coimbra"""
__email__ = 'luiscoimbraeng@outlook.com'
__version__ = '0.0.3'

from .Mail import Mail
from .API import API